@@ -1,7 +1,7 @@
 import numpy as np
 import pandas as pd
 from collections import defaultdict
-from scipy.stats import ttest_ind, mannwhitneyu
+from scipy.stats import mannwhitneyu
 from scipy.stats import chi2
 import warnings
 from functools import reduce
@@ -10,12 +10,8 @@ import pickle, os, sys
 warnings.simplefilter("ignore")
 from collections import defaultdict
 
-from .DataSet import DataSet
-from .BioNetwork import BioNetwork
-#from ...archive.qc import plot_silhouette
 from ._util_stat.multipletesting import pvalue_correction
 from ._feature import featuresObj 
-from .clustering import clustering
 from ._shuffle import shuffling
 # Disable
 def _blockPrint():
@@ -728,7 +724,7 @@ class iso_function():
         self.is_result = res
         self.dataset.isoobj = self
 
-        return res.reset_index(drop=True)[['gene', 'gene_symb', 'major_transcript', 'minor_transcript', 'switch_prob', 'corr', 'event_importance', 'exclusive_domains', 'p_value', 'adj_pval']]
+        return res.reset_index(drop=True)[['gene', 'gene_symb', 'major_transcript', 'minor_transcript', 'switch_prob', 'corr', 'diff', 'event_importance', 'exclusive_domains', 'p_value', 'adj_pval']]
 
 
     def _isoform_usage(self, eachgene, norm):
